import unittest as _unittest
import os as _os
import shutil as _shutil

import numpy as _np
import h5py as _h5py
import high5py as _hi5


def run_all_tests():
    test_loader = _unittest.defaultTestLoader
    test_suites = test_loader.discover(_os.path.dirname(__file__))
    _unittest.TextTestRunner(buffer=True).run(test_suites)


class TestHigh5Py(_unittest.TestCase):
    def setUp(self):
        self.outdir = _os.path.join(_os.path.dirname(__file__), 'tmp/')
        self.filepath = self.outdir + 'test_file.py'
        if not _os.path.isdir(self.outdir):
            _os.mkdir(self.outdir)
        self.generate_data()


    def tearDown(self):
        _shutil.rmtree(self.outdir, ignore_errors=True)


    def generate_data(self):
        # Types of data to create
        self.dtype_names = ['int', 'float', 'complex']
        self.array_types = ['scalar', 'vector', 'array']
        self.dset_names = ['%s/%s' % (d_type, a_type)
            for d_type in self.dtype_names for a_type in self.array_types]
        self.var_names = [name.replace('/', '_') for name in self.dset_names]
        self.num_rows = _np.random.randint(2, 10)
        self.num_cols = _np.random.randint(2, 10)

        # Make some scalar data (create an array first, so that the type is
        # _np.int32, not int, for later comparisons)
        self.int_scalar = _np.array(_np.random.randint(-10, 10))[()]
        self.float_scalar = _np.array(_np.random.rand())[()]
        self.complex_scalar = _np.array(
            _np.random.rand() + 1j * _np.random.rand())[()]

        # Make some vector data
        self.int_vector = _np.random.randint(-10, 10, size=self.num_rows)
        self.float_vector = _np.random.rand(self.num_rows)
        self.complex_vector = (
            _np.random.rand(self.num_rows) +
            1j * _np.random.rand(self.num_rows))

        # Make some array data
        self.int_array = _np.random.randint(
            -10, 10, size=(self.num_rows, self.num_cols))
        self.float_array = _np.random.rand(self.num_rows, self.num_cols)
        self.complex_array = (
            _np.random.rand(self.num_rows, self.num_cols) +
            1j * _np.random.rand(self.num_rows, self.num_cols))

        # Save to HDF5 file
        with _h5py.File(self.filepath, 'w') as fid:
            for dset_name, var_name in zip(self.dset_names, self.var_names):
                fid[dset_name] = getattr(self, var_name)


    # Check equality for both arrays and scalars
    def _helper_assert_equal(self, test_data, true_data):
        self.assertEqual(type(test_data), type(true_data))
        if isinstance(true_data, _np.ndarray):
            _np.testing.assert_array_equal(test_data, true_data)
        else:
            self.assertEqual(test_data, true_data)


    # Check that a dataset inside an HDF5 file is correct
    def _helper_check_dataset(self, filepath, dset_name, true_data, desc):

        # Split dataset name into group and dataset parts
        grp, dset = dset_name.split('/')

        # Open file
        with _h5py.File(filepath, 'r') as fid:

            # Check that group exists
            self.assertTrue(grp in list(fid))

            # Check that dataset exists
            self.assertTrue(dset in list(fid[grp]))

            # Check description of dataset
            self.assertEqual(
                fid['{}/{}'.format(grp, dset)].attrs['Description'], desc)

            # Check values
            saved_data = fid['{}/{}'.format(grp, dset)][()]
            self._helper_assert_equal(saved_data, true_data)


    # Check that existence of groups/datasets can be queried correctly
    def test_exists(self):
        with _h5py.File(self.filepath, 'w') as fid:
            fid['existing/dataset'] = 'data_string'
        self.assertTrue(_hi5.exists(self.filepath, 'existing'))
        self.assertTrue(_hi5.exists(self.filepath, 'existing/dataset'))
        self.assertFalse(_hi5.exists(self.filepath, 'existing/other'))
        self.assertFalse(_hi5.exists(self.filepath, 'nonexistent/dataset'))


    # Check that datasets can be loaded correctly
    def test_load_dataset(self):
        for dset_name, var_name in zip(self.dset_names, self.var_names):
            loaded_data = _hi5.load_dataset(self.filepath, dset_name)
            true_data = getattr(self, var_name)
            self._helper_assert_equal(loaded_data, true_data)


    # Check that datasets can be saved correctly, with and without compression
    def test_save_dataset(self):
        for dset_name, var_name in zip(self.dset_names, self.var_names):
            for comp_lvl in [None, 4, 9]:
                true_data = getattr(self, var_name)
                filepath = self.outdir + var_name + '_saved.h5'
                desc = dset_name + ' description'
                with _h5py.File(filepath, 'w') as fid:
                    fid['old_data'] = 'old_data'
                if 'scalar' in dset_name:
                    _hi5.save_dataset(
                        filepath, true_data, name=dset_name, description=desc)
                else:
                    _hi5.save_dataset(
                        filepath, true_data, name=dset_name, description=desc,
                        compression_level=comp_lvl)
                self._helper_check_dataset(filepath, dset_name, true_data, desc)
                with _h5py.File(filepath, 'r') as fid:
                    self.assertFalse('old_data' in fid['/'])


    # Check that datasets can be appended correctly, with and without
    # compression
    def test_append_dataset(self):
        for dset_name, var_name in zip(self.dset_names, self.var_names):
            for comp_lvl in [None, 4, 9]:
                true_data = getattr(self, var_name)
                filepath = self.outdir + var_name + '_saved.h5'
                desc = var_name + ' description'
                with _h5py.File(filepath, 'w') as fid:
                    fid['old_data'] = 'old_data'
                if 'scalar' in dset_name:
                    _hi5.append_dataset(
                        filepath, true_data, name=dset_name, description=desc)
                else:
                    _hi5.append_dataset(
                        filepath, true_data, name=dset_name, description=desc,
                        compression_level=comp_lvl)
                self._helper_check_dataset(filepath, dset_name, true_data, desc)
                with _h5py.File(filepath, 'r') as fid:
                    self.assertTrue('old_data' in fid['/'])


    # Check that datasets can be replaced correctly, with and without
    # compression
    def test_replace_dataset(self):
        for dset_name, var_name in zip(self.dset_names, self.var_names):
            for comp_lvl in [None, 4, 9]:
                true_data = getattr(self, var_name)
                replacement_data = 2 * true_data
                filepath = self.outdir + var_name + '_saved.h5'
                desc = dset_name + ' description'
                with _h5py.File(filepath, 'w') as fid:
                    fid['old_data'] = 'old_data'
                if 'scalar' in dset_name:
                    _hi5.append_dataset(
                        filepath, true_data, name=dset_name, description=desc)
                    _hi5.replace_dataset(
                        filepath, replacement_data, name=dset_name,
                        description=desc)
                else:
                    _hi5.append_dataset(
                        filepath, true_data, name=dset_name, description=desc,
                        compression_level=comp_lvl)
                    _hi5.replace_dataset(
                        filepath, replacement_data, name=dset_name,
                        description=desc, compression_level=comp_lvl)
                self._helper_check_dataset(
                    filepath, dset_name, replacement_data, desc)
                with _h5py.File(filepath, 'r') as fid:
                    self.assertTrue('old_data' in fid['/'])


    # Check that groups and datasets can be deleted correctly
    def test_delete(self):
        for grp in self.dtype_names:
            for dset in self.array_types:
                _hi5.delete(self.filepath, '{}/{}'.format(grp, dset))
                with _h5py.File(self.filepath, 'r') as fid:
                    self.assertFalse(dset in list(fid[grp]))
            _hi5.delete(self.filepath, grp)
            with _h5py.File(self.filepath, 'r') as fid:
                self.assertFalse(grp in list(fid))


    # Check that groups and datasets can be renamed correctly
    def test_rename(self):
        for grp in self.dtype_names:
            _hi5.rename(self.filepath, grp, grp + '_mod')
            new_grp = '{}_mod'.format(grp)
            with _h5py.File(self.filepath, 'r') as fid:
                self.assertFalse(grp in list(fid))
                self.assertTrue(new_grp in list(fid))

            for dset in self.array_types:
                new_dset = '{}_mod'.format(dset)
                _hi5.rename(
                    self.filepath,
                    '{}/{}'.format(new_grp, dset),
                    '{}/{}'.format(new_grp, new_dset))
                with _h5py.File(self.filepath, 'r') as fid:
                    self.assertTrue(new_dset in list(fid[new_grp]))


    # Check that attributes can be saved correctly
    def test_save_attributes(self):
        name = 'data'
        attributes = {'attr1': 1, 'attr2': 'two'}
        with _h5py.File(self.filepath, 'w') as fid:
            fid[name] = 'data'
            fid[name].attrs['old_attr'] = 'old'
        _hi5.save_attributes(self.filepath, attributes, name=name)
        with _h5py.File(self.filepath, 'r') as fid:
            for key, val in attributes.items():
                self.assertEqual(fid[name].attrs[key], val)
            self.assertFalse('old_attr' in fid[name].attrs)


    # Check that attributes can be appended correctly
    def test_append_attributes(self):
        name = 'data'
        attributes = {'attr1': 1, 'attr2': 'two'}
        with _h5py.File(self.filepath, 'w') as fid:
            fid[name] = 'data'
            fid[name].attrs['old_attr'] = 'old'
            _hi5.append_attributes(self.filepath, attributes, name=name)
        with _h5py.File(self.filepath, 'r') as fid:
            for key, val in attributes.items():
                self.assertEqual(fid[name].attrs[key], val)
            self.assertTrue('old_attr' in fid[name].attrs)


    # Check that HDF5 files can be correctly converted to NPZ files
    def test_to_npz(self):

        # Generate data
        datasets = {
            'x': _np.ones(4),
            'y': _np.arange(10),
            'z': _np.random.random((5, 6))}
        h5_path = self.outdir + 'data.h5'
        with _h5py.File(h5_path, 'w') as fid:
            for key, val in datasets.items():
                fid[key] = val
                fid['group0/{}'.format(key)] = val
                fid['group1/subgroup0/{}'.format(key)] = val
                fid['group1/subgroup1/{}'.format(key)] = val

        # Specify root level, which should save all datasets
        npz_path = self.outdir + 'data.npz'
        _hi5.to_npz(h5_path, npz_path)
        with _np.load(npz_path) as npz_data:
            for key, val in datasets.items():
                _np.testing.assert_array_equal(npz_data[key], val)
                _np.testing.assert_array_equal(
                    npz_data['group0_{}'.format(key)], val)
                _np.testing.assert_array_equal(
                    npz_data['group1_subgroup0_{}'.format(key)], val)
                _np.testing.assert_array_equal(
                    npz_data['group1_subgroup1_{}'.format(key)], val)

        # Test the specification of a group as the path, which will save only
        # the datasets in that group, and will also affect the names of the
        # arrays in the NPZ file
        npz_path = self.outdir + 'data.npz'
        _hi5.to_npz(h5_path, npz_path, name='group1')
        with _np.load(npz_path) as npz_data:
            for key, val in datasets.items():
                _np.testing.assert_array_equal(
                    npz_data['subgroup0_{}'.format(key)], val)
                self.assertEqual(
                    sorted(npz_data._files),
                    ['subgroup{:d}_{}.npy'.format(idx, key)
                     for idx in range(2)
                     for key in sorted(datasets.keys())])
        _hi5.to_npz(h5_path, npz_path, name='group1/subgroup1')
        with _np.load(npz_path) as npz_data:
            for key, val in datasets.items():
                _np.testing.assert_array_equal(npz_data[key], val)
                self.assertEqual(
                    sorted(npz_data._files),
                    ['{}.npy'.format(key) for key in sorted(datasets.keys())])

        # Test the specification of datasets as the path, which should save just
        # those datasets
        npz_path = self.outdir + 'data.npz'
        _hi5.to_npz(h5_path, npz_path, name='x')
        with _np.load(npz_path) as npz_data:
            _np.testing.assert_array_equal(npz_data['x'], datasets['x'])
            self.assertEqual(npz_data._files, ['x.npy'])
        _hi5.to_npz(h5_path, npz_path, name=['x', 'y'])
        with _np.load(npz_path) as npz_data:
            _np.testing.assert_array_equal(npz_data['x'], datasets['x'])
            _np.testing.assert_array_equal(npz_data['y'], datasets['y'])
            self.assertEqual(sorted(npz_data._files), ['x.npy', 'y.npy'])


    # Check that HDF5 files can be correctly converted from NPZ files
    def test_from_npz(self):

        # Generate data
        datasets = {
            'x': _np.ones(4),
            'y': _np.arange(10),
            'z': _np.random.random((5, 6))}
        npz_path = self.outdir + 'data.npz'
        _np.savez_compressed(npz_path, **datasets)

        # Convert data
        h5_path = self.outdir + 'data.h5'
        _hi5.from_npz(npz_path, h5_path)
        with _h5py.File(h5_path, 'r') as fid:
            for key, val in datasets.items():
                _np.testing.assert_array_equal(fid[key][()], val)


# Main routine
if __name__=='__main__':
    _unittest.main(verbosity=2)



"""
Module where the version is written.

'a' or 'alpha' means alpha version (internal testing)

'b' or 'beta' means beta version (external testing)

Append with .postN for post-release updates.  This may be necessary for changes
in packaging or documentation, as PyPI does not allow uploads of files with the
same filename (which corresponds to the version number).

References:
https://en.wikipedia.org/wiki/Software_versioning
https://legacy.python.org/dev/peps/pep-0440/#version-scheme
"""
__version__ = '0.1.post2'



import numpy as _np
import h5py as _h5py


def info(filepath, name='/', return_info=False):
    """Print and return information about HDF5 file/group/dataset.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    name: str, optional
        HDF5 group/dataset name (e.g., /group/dataset).  Defaults to root group
        ('/').
    return_info: bool, optional
        If True, return a dictionary of results.  Defaults to False.

    Returns
    -------
    info: dict, optional
        Dictionary of key, value pairs describing specified file/group/dataset.
        Only provided if return_info is True.
    """
    name = '{}'.format(name)
    with _h5py.File(filepath, 'r') as fid:
        info_dict = {'filename': fid.filename, 'name': fid[name].name}
        if isinstance(fid[name], _h5py.Group):
            info_dict['groups'] = [
                subname for subname in fid[name]
                if isinstance(fid['{}/{}'.format(name, subname)], _h5py.Group)]
            info_dict['datasets'] = [
                subname for subname in fid[name]
                if isinstance(
                    fid['{}/{}'.format(name, subname)],_h5py.Dataset)]
        if isinstance(fid[name], _h5py.Dataset):
            info_dict['datatype'] = fid[name].dtype
            info_dict['shape'] = fid[name].shape
            info_dict['size'] = fid[name].size
            info_dict['chunks'] = fid[name].chunks
            info_dict['compression'] = fid[name].compression
        info_dict['attributes'] = {
            key: val for key, val in fid[name].attrs.items()}
    for key, val in info_dict.items():
        print((
            '{:>' + '{:d}'.format(max([len(key) for key in info_dict.keys()]))
            + '}: {}').format(key, val))
    if return_info:
        return info_dict


def list_all(filepath, name='/', return_info=False):
    """List all groups and datasets in HDF5 file or group.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    name: str, optional
        HDF5 group name (e.g., /group).  Defaults to root group ('/').
    return_into: bool, optional
        If True, return a dictionary of results.  Defaults to False.

    Returns
    -------
    info: dict, optional
        Dictionary of key, value pairs describing specified file/group.  Only
        provided if return_info is True.
    """
    all_names = []
    all_items = {}
    with _h5py.File(filepath, 'r') as fid:
        fid[name].visit(all_names.append)
        max_len = max([len(name) for name in all_names])
        def print_item(name, obj):
            all_items[name] = str(obj)
            print(
                ('{:<' + '{:d}'.format(max_len) + '}    {}').format(name, obj))
        fid[name].visititems(print_item)
    if return_info:
        return all_items


def exists(filepath, name):
    """Determine if group/dataset name exists in HDF5 file.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    name: str
        HDF5 group/dataset name (e.g., /group/dataset).

    Returns
    -------
    exists: bool
        Boolean describing if path exists in HDF5 file.
    """
    avail_names = []
    with _h5py.File(filepath, 'r') as fid:
        fid.visit(avail_names.append)
    return name in avail_names


def load_dataset(filepath, name='data', start_index=0, end_index=-1):
    """Load dataset from HDF5 file.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    name: str, optional
        HDF5 dataset name (e.g., /group/dataset).  Defaults to 'data'.

    Returns
    -------
    data: array-like, scalar, or str
        Dataset values will be returned with same type they were saved (usually
        some sort of numpy array), except that single-element arrays will be
        returned as scalars.
    """
    with _h5py.File(filepath, 'r') as fid:
        data = fid[name][()]
    return data


def save_dataset(
    filepath, data, name='data', description=None, overwrite=True,
    compression_level=None):
    """Save dataset to HDF5 file (overwrites file by default).

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    data: array-like, scalar, or str
        Data to save.
    name: str, optional
        HDF5 dataset name (e.g., /group/dataset).  Defaults to 'data'.
    description: str, optional
        String describing dataset.  Description is saved as an HDF5 attribute of
        the dataset.  Defaults to None, for which no description is saved.
    overwrite: bool
        If True, saving overwrites the file.  Otherwise, data is appended to the
        file.  Defaults to True.
    compression_level: int or None, optional
        Integer from 0 to 9 specifying compression level for gzip filter, which
        is available on all h5py installations and offers good compression with
        moderate speed.  Defaults to None, for which no compression/filter is
        applied.
    """
    if overwrite:
        file_mode = 'w'
    else:
        file_mode = 'a'
    with _h5py.File(filepath, file_mode) as fid:
        if compression_level is not None:
            fid.create_dataset(
                name, data=data, compression='gzip',
                compression_opts=compression_level)
        else:
            fid.create_dataset(name, data=data)
        if description is not None:
            fid[name].attrs['Description'] = description


def delete(filepath, name):
    """Delete group/dataset in HDF5 file.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    name: str
        HDF5 name (e.g., /group/old_dataset).
    """
    with _h5py.File(filepath, 'a') as fid:
        del fid[name]


def rename(filepath, old_name, new_name, new_description=None):
    """Rename group/dataset in HDF5 file.

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    old_name: str
        Old HDF5 name (e.g., /group/old_dataset).
    new_name: str
        New HDF5 name (e.g., /group/new_dataset).
    description: str, optional
        New string describing dataset.  Description is saved as an HDF5
        attribute of the dataset.  Defaults to None, for which the old
        description is kept.
    """
    with _h5py.File(filepath, 'a') as fid:
        fid[new_name] = fid[old_name]
        if new_description is not None:
            fid[new_name].attrs['Description'] = new_description
        del fid[old_name]


def append_dataset(
    filepath, data, name='data', description=None, compression_level=None):
    """Append dataset to HDF5 file (never overwrites file).

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    data: array-like, scalar, or str
        Data to save.
    name: str, optional
        HDF5 dataset name (e.g., /group/dataset).  Defaults to 'data'.
    description: str, optional
        String describing dataset.  Description is saved as an HDF5 attribute of
        the dataset.  Defaults to None, for which no description is saved.
    compression_level: int or None, optional
        Integer from 0 to 9 specifying compression level for gzip filter, which
        is available on all h5py installations and offers good compression with
        moderate speed.  Defaults to None, for which no compression/filter is
        applied.
    """
    save_dataset(
        filepath, data, name=name, description=description, overwrite=False,
        compression_level=compression_level)


def replace_dataset(
    filepath, data, name='data', description=None, compression_level=None):
    """Replace/overwrite a dataset in an HDF5 file (do not overwrite the whole
    file).

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    data: array-like, scalar, or str
        Data to save.
    name: str, optional
        HDF5 dataset name (e.g., /group/dataset).  Defaults to 'data'.
    description: str, optional
        String describing dataset.  Description is saved as an HDF5 attribute of
        the dataset.  Defaults to None, for which no description is saved.
    compression_level: int or None, optional
        Integer from 0 to 9 specifying compression level for gzip filter, which
        is available on all h5py installations and offers good compression with
        moderate speed.  Defaults to None, for which no compression/filter is
        applied.
    """
    delete(filepath, name)
    append_dataset(
        filepath, data, name=name, description=description,
        compression_level=compression_level)


def save_attributes(filepath, attributes, name='data', overwrite=True):
    """Save HDF5 group/dataset attributes (overwrites existing attributes by
    default).

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    attributes: dict
        Attributes to save.
    name: str, optional
        HDF5 group/dataset name (e.g., /group/dataset).  Defaults to 'data'.
    overwrite: bool
        If True, saving overwrites existing attributes.  Otherwise, new
        attributes are appended to existing ones.  Defaults to True.
    """
    with _h5py.File(filepath, 'a') as fid:
        if overwrite:
            for key, val in fid[name].attrs.items():
                del fid[name].attrs[key]
        for key, val in attributes.items():
            fid[name].attrs[key] = val


def append_attributes(filepath, attributes, name='data'):
    """Append HDF5 group/dataset attributes (never overwrites existing
    attributes).

    Parameters
    ----------
    filepath: str
        Path to HDF5 file.
    attributes: dict
        Attributes to append.
    name: str, optional
        HDF5 group/dataset name (e.g., /group/dataset).  Defaults to 'data'.
    """
    save_attributes(filepath, attributes, name=name, overwrite=False)


def to_npz(h5_filepath, npz_filepath, name='/'):
    """Save an HDF5 group/dataset to NPZ (compressed numpy archive) format.
    Subgroups such as path/group/subgroup/dataset will be saved with array names
    such as path_group_subgroup_dataset.

    Parameters
    ----------
    h5_filepath: str
        Path to HDF5 file.
    npz_filepath: str
        Path to NPZ file.
    name: str, optional
        HDF5 group/dataset name (e.g., /group/dataset).  Defaults to root group
        ('/').
    """
    # Open file for processing
    with _h5py.File(h5_filepath, 'r') as fid:

        # Initialize root, paths to check
        dataset_names = []
        if isinstance(name, str):
            if isinstance(fid[name], _h5py.Dataset):
                root = '/'
                dataset_names = [fid[name].name]
                names_to_check = []
            else:
                root = name
                names_to_check = [name]
        else:
            root = '/'
            names_to_check = name

        # Process until there are no more paths to check
        while len(names_to_check) > 0:
            for subname in names_to_check:
                if isinstance(fid[subname], _h5py.Dataset):
                    dataset_names.append(fid[subname].name)
                    names_to_check.remove(subname)
                elif isinstance(fid[subname], _h5py.Group):
                    for subsubname in fid[subname]:
                        names_to_check.append(
                            fid['{}/{}'.format(subname, subsubname)].name)
                    names_to_check.remove(subname)

        # Generate dataset names for NPZ file starting from the specified root,
        # and replacing slashes with underscores, since NPZ files don't have
        # groups
        kwargs = {}
        for dsn in dataset_names:

            # Split off first instance of root
            key = root.join(dsn.split(root)[1:])

            # Remove leading slash, if any
            if key[0] == '/':
                key = key[1:]

            # Replace slashes with underscores
            key = key.replace('/', '_')

            # Add processed name
            kwargs[key] = fid[dsn][()]

    # Save data
    _np.savez_compressed(npz_filepath, **kwargs)


# Convert from NPZ (numpy archive) format
def from_npz(npz_filepath, h5_filepath):
    """Load data from an NPZ (compressed numpy archive) file and save to HDF5.
    NPZ array names are preserved.

    Parameters
    ----------
    npz_filepath: str
        Path to NPZ file.
    h5_filepath: str
        Path to HDF5 file.
    """
    # Open file for processing
    with _np.load(npz_filepath) as data:

        # Loop through arrays
        for idx, (key, val) in enumerate(data.items()):

            # Save to HDF5
            if idx == 0:
                save_dataset(h5_filepath, val, name=key)
            else:
                append_dataset(h5_filepath, val, name=key)



import os
from setuptools import setup, find_packages
from pkg_resources import parse_version


# Locate current location
here = os.path.abspath(os.path.dirname(__file__))

# Get the version from the relevant file
with open(os.path.join(os.path.join(here, 'high5py'), '_version.py')) as f:
    exec(f.read())

# Get the development status from the version string
parsed_version = str(parse_version(__version__))
if any(w in ['*a', '*alpha'] for w in parsed_version):
    devstatus = 'Development Status :: 3 - Alpha'
elif any(w in ['*b', '*beta'] for w in parsed_version):
    devstatus = 'Development Status :: 4 - Beta'
else:
    devstatus = 'Development Status :: 5 - Production/Stable'

# Setup
setup(
    name='high5py',
    version=__version__,
    description='Interact with HDF5 files using one-line function calls.',
    author='Jonathan Tu',
    url='http://high5py.readthedocs.io',
    maintainer='Jonathan Tu',
    license='Free BSD',
    classifiers=[
        # How mature is this project? Common values are
        # 3 - Alpha
        # 4 - Beta
        # 5 - Production/Stable
        devstatus,
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3'
    ],
    packages=['high5py'],
    package_dir={'high5py': 'high5py'},
    install_requires=['h5py', 'numpy']
)
